==> jei-1.21.9-fabric-25.0.0.2-sources.jar: mezz/jei/library/render/ItemStackRenderer.java <==
package mezz.jei.library.render;

import mezz.jei.api.ingredients.IIngredientRenderer;
import mezz.jei.api.ingredients.rendering.BatchRenderElement;
import mezz.jei.common.platform.IPlatformRenderHelper;
import mezz.jei.common.platform.Services;
import mezz.jei.library.render.batch.IItemStackBatchRenderer;
import mezz.jei.library.render.batch.SimpleItemStackBatchRenderer;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import org.jetbrains.annotations.Nullable;

import java.util.List;

public class ItemStackRenderer implements IIngredientRenderer<class_1799> {
	private final IItemStackBatchRenderer batchRenderer = new SimpleItemStackBatchRenderer();

	@Override
	public void render(class_332 guiGraphics, @Nullable class_1799 ingredient) {
		render(guiGraphics, ingredient, 0, 0);
	}

	@Override
	public void render(class_332 guiGraphics, @Nullable class_1799 ingredient, int posX, int posY) {
		if (ingredient != null) {
			class_310 minecraft = class_310.method_1551();
			class_327 font = getFontRenderer(minecraft, ingredient);
			guiGraphics.method_51445(ingredient, posX, posY);
			guiGraphics.method_51431(font, ingredient, posX, posY);
		}
	}

	@Override
	public void renderBatch(class_332 guiGraphics, List<BatchRenderElement<class_1799>> batchRenderElements) {
		batchRenderer.renderBatch(guiGraphics, this, batchRenderElements);
	}

	@Override
	public List<class_2561> getTooltip(class_1799 ingredient, class_1836 tooltipFlag) {
		class_310 minecraft = class_310.method_1551();
		class_1657 player = minecraft.field_1724;
		class_1792.class_9635 tooltipContext = class_1792.class_9635.method_59528(minecraft.field_1687);
		return ingredient.method_7950(tooltipContext, player, tooltipFlag);
	}

	@Override
	public class_327 getFontRenderer(class_310 minecraft, class_1799 ingredient) {
		IPlatformRenderHelper renderHelper = Services.PLATFORM.getRenderHelper();
		return renderHelper.getFontRenderer(minecraft, ingredient);
	}

	@Override
	public int getWidth() {
		return 16;
	}

	@Override
	public int getHeight() {
		return 16;
	}
}

==> jei-1.21.11-fabric-27.3.0.12-sources.jar: mezz/jei/library/render/ItemStackRenderer.java <==
package mezz.jei.library.render;

import mezz.jei.api.ingredients.IIngredientRenderer;
import mezz.jei.api.ingredients.rendering.BatchRenderElement;
import mezz.jei.common.platform.IPlatformRenderHelper;
import mezz.jei.common.platform.Services;
import mezz.jei.library.render.batch.IItemStackBatchRenderer;
import mezz.jei.library.render.batch.SimpleItemStackBatchRenderer;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_327;
import net.minecraft.class_332;
import org.jspecify.annotations.Nullable;

import java.util.List;

public class ItemStackRenderer implements IIngredientRenderer<class_1799> {
	private final IItemStackBatchRenderer batchRenderer = new SimpleItemStackBatchRenderer();

	@Override
	public void render(class_332 guiGraphics, @Nullable class_1799 ingredient) {
		render(guiGraphics, ingredient, 0, 0);
	}

	@Override
	public void render(class_332 guiGraphics, @Nullable class_1799 ingredient, int posX, int posY) {
		if (ingredient != null) {
			class_310 minecraft = class_310.method_1551();
			class_327 font = getFontRenderer(minecraft, ingredient);
			guiGraphics.method_51445(ingredient, posX, posY);
			guiGraphics.method_51431(font, ingredient, posX, posY);
		}
	}

	@Override
	public void renderBatch(class_332 guiGraphics, List<BatchRenderElement<class_1799>> batchRenderElements) {
		batchRenderer.renderBatch(guiGraphics, this, batchRenderElements);
	}

	@Override
	public List<class_2561> getTooltip(class_1799 ingredient, class_1836 tooltipFlag) {
		class_310 minecraft = class_310.method_1551();
		class_1657 player = minecraft.field_1724;
		class_1792.class_9635 tooltipContext = class_1792.class_9635.method_59528(minecraft.field_1687);
		return ingredient.method_7950(tooltipContext, player, tooltipFlag);
	}

	@Override
	public class_327 getFontRenderer(class_310 minecraft, class_1799 ingredient) {
		IPlatformRenderHelper renderHelper = Services.PLATFORM.getRenderHelper();
		return renderHelper.getFontRenderer(minecraft, ingredient);
	}

	@Override
	public int getWidth() {
		return 16;
	}

	@Override
	public int getHeight() {
		return 16;
	}
}
